#set of functions, directly/indirectly involved, in oneChannelGUI exonmenu
#oneChannelGUI AptMidas runs the Affymetrix APT MiDAS program to detect putative alternative splicing, works at exon level only
           #contains libraryFilesDir present in filemenu.R
           #         .aptDir present in filemenu.R
#oneChannelGUI spliceIndex calculates the spliceIndex, the SI calculation without any filter is too long.
#oneChannelGUI erankProdAltSpl calculates p-values by RankProd for the rpesence of differentially expressed exons, work on the SI
#oneChannelGUI inspecting.splice.index plots on a PDF file the behaviour of SI, i.e. evaluates graphically the rpesence of alternative splcing, at gene level on a set of transcripts derived for  some filtering procedure
#oneChannelGUI inspecting.one.splice.index as the previous but for one gene only and line command only mode TO BE REVISED!!!
#oneChannelGUI  midasFilter filters gene/exon level data by MiDAS p-values
#oneChannelGUI  erankProdAltSplFilter  filters gene/exon level data by RankProd p-values (to be made it will use the association of core gene/exon level ids present in data)
#oneChannelGUI  crosshybFilter this filter uses crooshyb or xhyb data to remove cross hybridizing exon probe sets see their help for more info
#oneChannelGUI  siFilter this function filters gene/exon data on the basis of the absolute SI mean difference
################################################################################
#graphical interface to APT midas for alternative splicing detection
"AptMidas" <- function(){
          #error if no data are loaded
          Try(whichArrayPlatform <- get("whichArrayPlatform",envir=affylmGUIenvironment))
          if(whichArrayPlatform ==""){
              Try(tkmessageBox(title="Exons analysis",message="No arrays have been loaded.	Please try New or Open from the File menu.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
          }    
          #########################

     #loading gene/exon data
     Try(NormalizedAffyData.Available <- get("NormalizedAffyData.Available", env=affylmGUIenvironment))
     Try(exonAffyData.Available <- get("exonAffyData.Available", env=affylmGUIenvironment))

     if(NormalizedAffyData.Available & exonAffyData.Available){
         Try(Targets <- get("Targets",envir=affylmGUIenvironment))
         Try(libDir.Available <- get("libDir.Available", env=affylmGUIenvironment))
         #check if the library data for exon analysis has been set
         if (libDir.Available){ 
                                 Try(whichLib <- get("whichLib", env=affylmGUIenvironment)) 
                                 Try(libDir <- get("libDir", env=affylmGUIenvironment))
                                 Try(content.libDir <- dir(libDir))
                                 Try(exonlib.name <- paste(libDir, content.libDir[intersect(grep('.mps$',content.libDir), intersect(grep(whichLib[[1]][1],content.libDir), grep(whichLib[[1]][2],content.libDir)))], sep=""))
         } else {
         #select the directory in which are present the library data for expression console analysis
                                 Try(libDir <- "")
                                 Try(libDir <- libraryFilesDir())
                                 if(libDir != ""){
                                                     Try(libDir <- paste(libDir, "/", sep=""))
                                                     Try(content.libDir <- dir(libDir))
                                                     if(length(grep(tmp[[1]][1],content.libDir)) == 0){
                                                            Try(tkmessageBox(title="Gene/exon libraries Dir",message=paste("The selected folder does not contain ", tmp[[1]][1], " library files!\n Download them from Affymetrix web site!", sep=""),icon="error"))
                                                            Try(return())
                                                     }
                                                     Try(ctrl.name <- paste(libDir, content.libDir[intersect(grep(tmp[[1]][1],content.libDir), grep('controls.ps$',content.libDir))], sep=""))
                                                     Try(ctrl <- read.table(ctrl.name, sep="\t", header=T, as.is=T))
                                                     Try(exonlib.name <- paste(libDir, content.libDir[intersect(grep('.mps$',content.libDir), intersect(grep(tmp[[1]][1],content.libDir), grep(tmp[[1]][2],content.libDir)))], sep=""))
                                                     Try(exonlib <- read.table(exonlib.name, sep="\t", header=T, as.is=T))
                                                     Try(ctrl.exonlib <- list("controls"=ctrl, "exon.library"=exonlib))
                                                     Try(assign("libDir.Available",TRUE,affylmGUIenvironment))
                                                     Try(assign("libDir", tt ,affylmGUIenvironment))#locate here the library files as a list of data.frames
                                                     Try(assign("exprConsoleLibs.Available",TRUE,affylmGUIenvironment))
                                                     Try(assign("exprConsoleLibs", ctrl.exonlib ,affylmGUIenvironment))
                                                     Try(cat(""))
                                                  } else {
                                                           Try(tkmessageBox(title="Gene/exon libraries Dir",message="You have not defined the directory where gene/exon libraries are installed!",icon="error"))
			                                                     return()
                                                    }
  
         }
         #check id APT library is installed
         Try(aptDir.Available <- get("aptDir.Available", env=affylmGUIenvironment))
         if(aptDir.Available){ 
                               Try(aptDir <- get("aptDir", env=affylmGUIenvironment)) 
         } else{
                               Try(whereApt <- "")
                               Try(whereApt <- .aptDir())
                               if(whereApt != ""){
                               #APT dir
                               if(length(grep("apt-probeset-summarize", dir(paste(whereApt, "/bin", sep="")))) == 0){
                                                  Try(tkmessageBox(title="APT tools dir ",message="You have not correctly defined the main folder where APT tools are located!",icon="error"))
                                                  Try(return())
                               } 
                               Try(assign("aptDir.Available",TRUE,affylmGUIenvironment))
                               Try(assign("aptDir", whereApt ,affylmGUIenvironment))
                                                                
               }
         }                                           
         Try(NormalizedAffyData <- get("NormalizedAffyData", env=affylmGUIenvironment))
         Try(exonAffyData <- get("exonAffyData", env=affylmGUIenvironment))
         
         #defining the temp file containing target info for apt
         Try(tempTarget <- tempfile(pattern = "target", tmpdir = getwd()))
         Try(tempTarget <- sub( "\\\\","/",tempTarget)) #changing double backslach with slash
         Try(write.table(Targets[,2:3], tempTarget, sep="\t", row.names =F, col.names = c("cel_files", "group_id"))) 

         #defining the file with the gene level data
         Try(tempGlevel <- tempfile(pattern = "glevels", tmpdir = getwd()))
         Try(tempGlevel <- sub( "\\\\","/",tempGlevel)) #changing double backslach with slash
         Try(gTmp<- as.data.frame(exprs(NormalizedAffyData)))
         Try(gTmp <- cbind(as.character(rownames(gTmp)), gTmp))
         Try(colnames(gTmp)[1] <- "probeset_id")
         Try(write.table(gTmp, tempGlevel, sep="\t", row.names=F))
  
         #defining the file with the exon level data
         Try(tempElevel <- tempfile(pattern = "elevels", tmpdir = getwd()))
         Try(tempElevel <- sub( "\\\\","/",tempElevel)) #changing double backslach with slash
         Try(eTmp<- as.data.frame(exprs(exonAffyData)))
         Try(eTmp <- cbind(as.character(rownames(eTmp)), eTmp))
         Try(colnames(eTmp)[1] <- "probeset_id")
         Try(write.table(eTmp, tempElevel, sep="\t", row.names=F))

          
          #defining the out dir
         Try(tempMidas <- tempfile(pattern = "outMidas", tmpdir = getwd()))#creating a temp outfile
         Try(tempMidas <- sub( "\\\\","/",tempMidas)) #changing double backslach with slash
         
         #Try(cat("\n",paste(aptDir,"/bin/apt-midas ", " --cel-files ", tempTarget, " -g ", tempGlevel, " -e ", tempElevel, " -m ", exonlib.name, " -o ",tempMidas, sep=""),"\n"))

         Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
         Try(cat("\nMidas alternative splice analysis started........\n"))
         Try(system(paste(aptDir,"/bin/apt-midas "," --cel-files ", tempTarget, " -g ", tempGlevel, " -e ", tempElevel, " -m ", exonlib.name, " -n " , " -o ",tempMidas, " --no-logtrans",sep=""), wait = T))
         Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
         Try(cat("....saving MiDAS p-values\n"))
         #check if all files will produce an header of 16 rows
         Try(midas.p <- read.table(paste(tempMidas, "/midas.pvalues.txt", sep=""), header=T, skip=16, as.is=T))
         assign("midas.p" , midas.p, affylmGUIenvironment)
         assign("midas.p.Available" , TRUE, affylmGUIenvironment)
         Try(tkdelete(.affylmGUIglobals$mainTree,"AptMidas.Status"))
         Try(tkinsert(.affylmGUIglobals$mainTree,"end","AptMidas","AptMidas.Status" ,text="Available",font=.affylmGUIglobals$affylmGUIfontTree))
         #col 1 exon probe ids, col 2 gene probe ids
#        Try(cat("....saving Splice Index values\n"))
#        Try(spliceIdx <- read.table(paste(tempMidas, "/midas.normalized.txt", sep=""), header=T, skip=16, as.is=T))
#        Try(which.duplicated <- duplicated(spliceIdx[,1]))
#        Try(spliceIdx <- spliceIdx[!which.duplicated,])
#        Try(assign("spliceIndexData",spliceIdx,affylmGUIenvironment))
        #the first two columns are exon probe set ids and transcript ids 
#        Try(assign("spliceIndexData.Available",TRUE,affylmGUIenvironment))
#        Try(tkdelete(.affylmGUIglobals$mainTree,"spliceIndex.Status"))            
#        Try(tkinsert(.affylmGUIglobals$mainTree,"end","spliceIndex","spliceIndex.Status" ,text="Available",font=.affylmGUIglobals$affylmGUIfontTree))
        Try(cat("....Midas alternative splice analysis ended\n"))
        Try(hist(affylmGUIenvironment$midas.p[,3], main="MiDAS Splice Index p-values"))
 
        Try(tkmessageBox(title="APT MiDAS",message="The histogram of MiDAS p-values is shown in the main R window."))
         
   }
}
################################################################################

#Genomewide analysis of mRNA processing in yeast using splicing-specific microarrays, Clark,
#T, Sugnet, C, Ares, M. Science 2002 May 3;296(5569):907-10
#converting exon expression data in splice index
"spliceIndex" <- function(){
     Try(ptm <- proc.time())
     #error if no data are loaded
     Try(whichArrayPlatform <- get("whichArrayPlatform",envir=affylmGUIenvironment))
     if(whichArrayPlatform ==""){
              Try(tkmessageBox(title="Exons analysis",message="No arrays have been loaded.	Please try New or Open from the File menu.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
    }    
    #########################
    Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
    Try(exprConsoleLibs <- get("exprConsoleLibs", env=affylmGUIenvironment))
    Try(NormalizedAffyData <- get("NormalizedAffyData", env=affylmGUIenvironment))
    Try(exonAffyData <- get("exonAffyData", env=affylmGUIenvironment) )
    Try(spliceIdx <- NULL)#splice index
    Try(spliceIdxIds <- NULL)#exon and gene ids
    
    Try(exon.counts <- 0)
    for (i in 1: dim(exprs(NormalizedAffyData))[1]){
             #catching oexon info related to a specific gene probeset_id
             Try(geneExonsIds <- as.vector(unlist(strsplit(exprConsoleLibs$exon.library$"probeset_list"[
                            which(as.character(exprConsoleLibs$exon.library$"probeset_id")==
                            featureNames(NormalizedAffyData)[i])], split=" "))))
             Try(exon.counts <- exon.counts +  length(geneExonsIds))
             Try(geneExons <- exprs(exonAffyData[which(featureNames(exonAffyData)%in%geneExonsIds),]))
             Try(gene.exprs <- as.vector(unlist(exprs(NormalizedAffyData[featureNames(NormalizedAffyData)[i],]))))
             Try(gene.exprs <- matrix(rep(gene.exprs, dim(geneExons)[1]), ncol=dim(geneExons)[2], byrow = TRUE))
             Try(spliceIdx <- rbind(spliceIdx, (geneExons -  gene.exprs)))#this is an exon matrix
             #adding exon and gene ids to be identical in structure to the midas normalized expr output
             Try(geneGeneIds <- rep(featureNames(NormalizedAffyData)[i], length(geneExonsIds)))
             Try(tmpIds <- cbind(geneExonsIds, geneGeneIds))
             Try(spliceIdxIds <- rbind(spliceIdxIds, tmpIds))
             
              
    }        
    Try(spliceIdx <- data.frame(spliceIdxIds, spliceIdx)) 
    Try(assign("spliceIndexData",spliceIdx,affylmGUIenvironment))
    Try(assign("spliceIndexData.Available",TRUE,affylmGUIenvironment))
    Try(tkdelete(.affylmGUIglobals$mainTree,"spliceIndex.Status"))            
    Try(tkinsert(.affylmGUIglobals$mainTree,"end","spliceIndex","spliceIndex.Status" ,text="Available",font=.affylmGUIglobals$affylmGUIfontTree))
    Try(cat("\n Analyzed exons ", exon.counts, "\n"))
    Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
    Try(usedtime <- proc.time() - ptm)
    Try(cat("\nUsed CPU time (min) ",usedtime[3]/60,"\n")) 
}
################################################################################

#detecting splice index using rank product tool
#works at exon level
"erankProdAltSpl" <-function(){
   Try(ptm <- proc.time())
   require(RankProd) || stop("library RankProd could not be found !")
   #error if no data are loaded
   Try(whichArrayPlatform <- get("whichArrayPlatform",envir=affylmGUIenvironment))
   if(whichArrayPlatform ==""){
              Try(tkmessageBox(title="Exons analysis",message="No arrays have been loaded.	Please try New or Open from the File menu.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
  }    
  #########################

          Try(targets <-  affylmGUIenvironment$Targets$Target)
          Try(targets <- strsplit(targets, "_"))
          Try(targets <- t(as.data.frame(targets)))
          if(dim(targets)[2]==1){
              Try(target.unique <- unique(targets[,1]))
              Try(cl <- rep(0,dim(targets)[1]))
              Try(cl[which(targets[,1]==target.unique[2])] <- 1)
              Try(origin <- rep(1,dim(targets)[1]))
          } else if(dim(targets)[2]==2){
               Try(target.unique <- unique(targets[,1]))
               Try(cl <- rep(0,dim(targets)[1]))
               Try(cl[which(targets[,1]==target.unique[2])] <- 1)
               Try(origin <- as.numeric(targets[,2]))
          } else{
             Try(tkmessageBox(title="Alternative splicing detection by RankProd analysis",message="The target file is not in the right format!\nCovariates should be linked to their origin (a number) by an underscore.\nIf the origin is only one it is not mandatory to indicate it"))
             return()
          }  

   if(length(target.unique) == 2){
         Try(spliceIndexData.Available <- get("spliceIndexData.Available", env=affylmGUIenvironment) )
         if(spliceIndexData.Available){
                   Try(spliceIndexData <- get("spliceIndexData", env=affylmGUIenvironment) )#is amatrix
                   Try(spliceIndexData.ids <- spliceIndexData[,1:2])
                   Try(spliceIndexData.ids <- paste(as.character(spliceIndexData[,1]),as.character(spliceIndexData[,2]), sep="|"))
                   Try(rownames(spliceIndexData) <- spliceIndexData.ids)
                   Try(spliceIndexData <- spliceIndexData[,3:dim(spliceIndexData)[2]])

                   Try(mean.class1 <- apply(spliceIndexData[,which(cl==0)], 1, mean))
                   Try(mean.class2 <- apply(spliceIndexData[,which(cl==1)], 1, mean))
                   Try(deltaSI <- mean.class2 - mean.class1)
                   Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
                   #Try(outTableAltSpl <- NULL)
                   if(dim(targets)[2]==1){   
                                 Try(RP.out <- RP(spliceIndexData, cl, num.perm = 100, logged = TRUE, na.rm = FALSE, plot = FALSE, rand = 1234567))#gene.names = rownames(spliceIndexData)
                   }     else if(dim(targets)[2]==2){
                                 Try(RP.out <- RPadvance(spliceIndexData, cl, origin, num.perm = 100, logged = TRUE, na.rm = FALSE, plot = FALSE, rand = 1234567, ))#gene.names = rownames(spliceIndexData)
                   }
                   
                  Try(outTableAltSpl <- cbind(rownames(spliceIndexData), RP.out$pval[1], RP.out$pval[2], deltaSI)) #false positive predictions (pfp)  i.e. FDR
                  Try(names(outTableAltSpl) <- c("exon_transcript_id", "p-val class1 < class2", "p-val class1 > class2", "deltaSI"))
                  Try(assign("AltSplRP.e.p" , outTableAltSpl, affylmGUIenvironment))
                  Try(assign("AltSplRP.e.Available" , TRUE, affylmGUIenvironment))
                  Try(outTableAltSpl <- get("AltSplRP.e.p", affylmGUIenvironment))
                  Try(tkdelete(.affylmGUIglobals$mainTree,"AltSplRP.e.Status")) 
                  Try(tkinsert(.affylmGUIglobals$mainTree,"end","AltSplRP","AltSplRP.e.Status" ,text="Available exon level",font=.affylmGUIglobals$affylmGUIfontTree))
                  par(mfrow=c(1,3))
                  Try(hist(outTableAltSpl[,2], main=names(outTableAltSpl)[2], xlab=""))
                  Try(hist(outTableAltSpl[,3], main=names(outTableAltSpl)[3], xlab=""))
                  Try(hist(outTableAltSpl[,4], main=names(outTableAltSpl)[4], xlab=""))
                  Try(tkmessageBox(title="RP alternative splicing detection",message="RP alternative splicing detectin is finished.\nResults can be exported with the Export function in the exon menu.\nHistograms of results are available in the main R window."))
                  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
         } else {
                   Try(tkmessageBox(title="Alternative splicing detection by RankProd analysis",message="Splice Index was not yet calculated"))
         }

      }else {
                    #groups definition
                    Try(tkmessageBox(title="Alternative splicing detection by RankProd analysis",message="One/Multi class unpaired case analysis not implemented, yet."))
       }
       Try(usedtime <- proc.time() - ptm)
       Try(cat("\nUsed CPU time (min) ",usedtime[3]/60,"\n"))        
}
################################################################################

#the part related to model selection should be refined actually the selection of value related to se and R-squared anre not sufficiently nice

"inspecting.splice.index" <-function(){
  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
  #error if no data are loaded
  Try(whichArrayPlatform <- get("whichArrayPlatform",envir=affylmGUIenvironment))
  if(whichArrayPlatform ==""){
              Try(tkmessageBox(title="Exons analysis",message="No arrays have been loaded.	Please try New or Open from the File menu.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
  }    
  Try(spliceIndexData.Available <- get("spliceIndexData.Available", env=affylmGUIenvironment) )
  if(spliceIndexData.Available){
                   Try(Targets <- get("Targets", env=affylmGUIenvironment) )
                   Try(targets.unique <- unique(Targets$Target))
                   if(length(targets.unique)!=2){
                         Try(tkmessageBox(title="Inspecting exon profiles", message="This analysis can be applied \nonly to two groups experiments!",type="ok",icon="error"))
                         Try(return())
                   }
                   Try(spliceIndexData <- get("spliceIndexData", env=affylmGUIenvironment) )
                   Try(exprConsoleLibs <- get("exprConsoleLibs", env=affylmGUIenvironment))
                   Try(NormalizedAffyData <- get("NormalizedAffyData", env=affylmGUIenvironment))
                   Try(midas.p.Available <- get("midas.p.Available", env=affylmGUIenvironment))
                   Try(AltSplRP.e.Available <- get("AltSplRP.e.Available", env=affylmGUIenvironment))
 #####################################################################################################################
 #selecting the file containing the gene probe sets to be investigated at exon level and the output name
                  Try(tkmessageBox(title="Inspecting exon profiles", message="Open the file containing the list of gene-level probe sets\n to be inspected for the presence of alernative splicing.",type="ok",icon="info"))
                  Try(tempFileName <- tclvalue(tkgetOpenFile(filetypes="{{Text Files} {.txt}} {{All files} *}")))
                        if(!nchar(tempFileName))
                        {
                           tkfocus(.affylmGUIglobals$ttMain)
                           return()
                        }
                        Try(mySel<-read.table(tempFileName, sep="\t", header=F, as.is=TRUE))
                        if(dim(mySel)[2]==1){
                              Try(mySel <- as.character(unlist(mySel[,1])))
                              Try(tempFileName <- as.character(unlist(strsplit(tempFileName[[1]], "/"))))
                              Try(tempFileName <- tempFileName[length(tempFileName)])
                              Try(tempFileName <- sub(".txt", "", tempFileName))
                              Try(assign("FileNameText",paste("alt.sp.out.",tempFileName,".pdf", sep=""),affylmGUIenvironment))
                        } else Try(tkmessageBox(title="Inspecting exon profiles",message=paste("File should contain\nonly a column with\nAffymetrix ids")))  

########################################################################################################################################
                   Try(FileNameText <- get("FileNameText", affylmGUIenvironment))
                   pdf(FileNameText)
                   Try(selected.altsplg <- NULL)
                   for (i in 1: length(mySel)){
                   #catching oexon info related to a specific gene probeset_id
                              Try(geneExonsIds <- as.vector(unlist(strsplit(exprConsoleLibs$exon.library$"probeset_list"[
                                     which(as.character(exprConsoleLibs$exon.library$"probeset_id")==
                                     mySel[i])], split=" "))))
#                              #transposed the exon matrix
                              Try(geneExons <- spliceIndexData[which(as.character(spliceIndexData[,1])%in%geneExonsIds),])#transpose becasue I need to add the labels
                              Try(rownames(geneExons) <- as.character(geneExons[,1]))
                              Try(geneExons <- geneExons[,3:dim(geneExons)[2]])
                              ##p.value calculation for exons
                              #adding MiDAS p-values                              
                              if(midas.p.Available){
                                    Try(midas.p <- get("midas.p", env=affylmGUIenvironment))
                                    Try(tmp <- midas.p[which(midas.p[,1]%in%geneExonsIds),c(1,3)])
                                    Try(geneExonsMiDAS <- -log2(as.numeric(tmp[,2])))
                                    Try(names(geneExonsMiDAS) <- as.character(tmp[,1]))
                              }
                              #plotting midas

                              if(AltSplRP.e.Available){
                                    Try(AltSplRP.e.p <- get("AltSplRP.e.p", env=affylmGUIenvironment))
                                    Try(myEids <- strsplit(as.character(AltSplRP.e.p[,1]), "\\|"))
                                    Try(myEids <- sapply(myEids, function(x)x[1]))
                                    Try(AltSplRP.e.p[,1] <- myEids)
                                    Try(tmp <- AltSplRP.e.p[which(AltSplRP.e.p[,1]%in%geneExonsIds),c(1,2)])# "p-val class1 < class2" 
                                    Try(geneExonsRP1 <- -log2(as.numeric(tmp[,2])))
                                    Try(names(geneExonsRP1) <- as.character(tmp[,1]))
                                    Try(tmp <- AltSplRP.e.p[which(AltSplRP.e.p[,1]%in%geneExonsIds),c(c(1,3))])#  "p-val class1 > class2"
                                    Try(geneExonsRP2 <- -log2(as.numeric(tmp[,2])))
                                    Try(names(geneExonsRP2) <- as.character(tmp[,1]))
                                    par(mfrow=c(1,3))
                                    #mapping common alt splicing in common between MiDAS rank prod
                                    Try(whichMiDAS <- names(geneExonsMiDAS)[which(geneExonsMiDAS >= -log2(0.05))])
                                    Try(whichRP1 <- names(geneExonsRP1)[which(geneExonsRP1 >= -log2(0.05))])
                                    Try(whichRP2 <- names(geneExonsRP2)[which(geneExonsRP2 >= -log2(0.05))])
                                    Try(altcommon <- intersect(whichMiDAS, union(whichRP1, whichRP2)))
                                    if(length(altcommon)>0){
                                        Try(altcommon1 <- paste(altcommon,collapse = "|")) 
                                        Try(myalt <- paste(featureNames(NormalizedAffyData)[i], altcommon1, sep = "|"))
                                    } else {Try(myalt <- featureNames(NormalizedAffyData)[i])}
                                    Try(selected.altsplg <- c(selected.altsplg, myalt))
                                    #############################################################
                   
                                    Try(myylim <- max(as.numeric(c(geneExonsMiDAS, geneExonsRP1, geneExonsRP2))))
                                    Try(plot(seq(1,length(geneExonsMiDAS)),geneExonsMiDAS, xlab="exon index", ylab="-log2(p-value)", ylim=c(0,myylim),pch=19,main=paste("MiDAS/RP results for ",featureNames(NormalizedAffyData)[i],"\nglevel probe set", sep="")))
                                    Try(abline(h=-log2(0.05), lty=2))
                                    Try(points(seq(1,length(geneExonsRP1)),geneExonsRP1, pch=24, bg="red"))
                                    Try(points(seq(1,length(geneExonsRP2)),geneExonsRP2, pch=25, bg="green"))
                                    Try(abline(v=which(names(geneExonsMiDAS)%in%altcommon), lty=2, col="yellow"))
                                    
                                    Try(plot(geneExonsMiDAS, geneExonsRP1, pch=24, bg="red", xlab="MiDAS", ylab="RP", xlim=c(0,myylim), ylim=c(0,myylim), main="Consistency between MiDAS and RP results")) 
                                    Try(points(geneExonsMiDAS, geneExonsRP2, pch=25, bg="green"))
                                    Try(abline(h=-log2(0.05), lty=2))
                                    Try(abline(v=-log2(0.05), lty=2))
                              } else{
                                    par(mfrow=c(1,2))
                                    Try(plot(seq(1,dim(geneExons)[1]),geneExonsMiDAS, xlab="exon index", ylab="-log2(p-value)", pch=19,main=paste("MiDAS/RP results for ",featureNames(NormalizedAffyData)[i],"\nglevel probe set", sep="")))
                                    Try(abline(h=-log2(0.05), lty=2))
                              }
                              #defining  SI behaviour
                              Try(geneExons <- t(geneExons))#transpose becasue I need to add the labels
                              
                              Try(exonIndexLablesExons <- NULL)
                              Try(for(j in 1: dim(geneExons)[2]){
                                        exonIndexLablesExons    <-  c(exonIndexLablesExons, rep(j,dim(geneExons)[1]))
                                  }
                              )    
                             
                              Try(exonIndex <-  seq(1,dim(geneExons)[2]))#this is needed since geneExons are going to be transformed in a vector
                              Try(exonIndexLablesSamples <-  rep(Targets$Target,dim(geneExons)[2]))

                              Try(geneExons <- as.numeric(unlist(geneExons)))  #when unlisting data are unlisted on a column base!
                              if( length(geneExons) > 2 & length(targets.unique)==2){
                                      #defining the index vector for model plotting
                                           Try(index.1 <- NULL)
                                           Try(index.2 <- NULL)
                                           Try(for(j in 1: length(exonIndex)){
                                                  index.1 <-  c(index.1, intersect(which(exonIndexLablesExons==j), 
                                                                  which(exonIndexLablesSamples==targets.unique[1])))
                                                  index.2 <-  c(index.2, intersect(which(exonIndexLablesExons==j), 
                                                                  which(exonIndexLablesSamples==targets.unique[2])))
                                               }
                                           )
                                           Try(plot(exonIndexLablesExons, geneExons, type="n", xlab="Exon index", ylab="Splice Index", 
                                                           main=paste("SI behaviour in ",featureNames(NormalizedAffyData)[i],"\nglevel probe set", sep="")))
                                           Try(points(exonIndexLablesExons[index.1], geneExons[index.1], pch=19, col="black", cex=0.7))
                                           Try(points(exonIndexLablesExons[index.2], geneExons[index.2], pch=19, col="red", cex=0.7))
                                           if(AltSplRP.e.Available){
                                                Try(abline(v=which(names(geneExonsMiDAS)%in%altcommon), lty=2, col="yellow"))
                                           }
                                           ##############.............
                                      #     Try(lm.geneExons <- lm(geneExons[index.1] ~ exonIndexLablesExons[index.1]))
                                      #     Try(abline(lm.geneExons, lty=2, col="black"))
                                      #     Try(lm.geneExons <- lm(geneExons[index.2] ~ exonIndexLablesExons[index.2]))
                                      #     Try(abline(lm.geneExons, lty=2, col="red"))
                                      #     Try(legend(0,max(geneExons), legend=targets.unique,pch=19, col=c("black","red")))
                                      #     
                                      #     Try(plot(geneExons1,geneExonsPval,cex=0.5,xlab="Average mean Splice Index", 
                                      #               ylab="Significance of splicing events\n-log2(p-value)", main=targets.unique[1]))                
                                      #     Try(abline(h=-log2(Pval),lty=2, col="green"))
                                      #     Try(text(geneExons1[intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold))],
                                      #                geneExonsPval[intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold))],
                                      #                labels=c(as.character(intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold)))))
                                      #     )
                                      #    
                                      #     Try(plot(geneExons2,geneExonsPval,cex=0.5,xlab="Average mean Splice Index", 
                                      #               ylab="Significance of splicing events\n-log2(p-value)", main=targets.unique[2]))                
                                      #     Try(abline(h=-log2(Pval),lty=2, col="green"))
                                      #     Try(text(geneExons2[intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold))],
                                      #                geneExonsPval[intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold))],
                                      #                labels=c(as.character(intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold)))))
                                      #     )     
                              } else {Try(plot(seq(1,2), seq(1,2), type="n", xlab="Exon index", ylab="Splice Index", 
                                                           main=paste("No plot available, \nthere are less than 3 exons in ",featureNames(NormalizedAffyData)[i],"\nglevel probe set", sep="")))
                              }
                            }
                   Try(selected.altsplg <- as.data.frame(selected.altsplg))
                   Try(names(selected.altsplg) <- "glevel id|exon level ids ") 
                   Try(write.table(selected.altsplg, file=paste(FileNameText, ".txt", sep=""), sep="\t", row.names=F))          
                   Try(dev.off())
                   Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
                   Try(tkmessageBox(title="Inspecting exon profiles",message=paste("Plots and ids of spliced exons are saved respectively in ", FileNameText, paste(FileNameText, ".txt", sep="") , sep=" ") , type="ok", icon="info"))
    } else {
                   Try(tkmessageBox(title="Inspecting exon profiles",message="Splice Index was not yet calculated"))
    }
    Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))  
}
################################################################################

#the part related to model selection should be refined actually the selection of value related to se and R-squared anre not sufficiently nice

"inspecting.one.splice.index" <-function(transcriptID, SpliceIndexDiff, PvalExon){
      #error if no data are loaded
      Try(whichArrayPlatform <- get("whichArrayPlatform",envir=affylmGUIenvironment))
      if(whichArrayPlatform ==""){
              Try(tkmessageBox(title="Exons analysis",message="No arrays have been loaded.	Please try New or Open from the File menu.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
      }    
      #########################

    spliceIndexData.Available <- get("spliceIndexData.Available", env=affylmGUIenvironment)
    if(spliceIndexData.Available){
                   Targets <- get("Targets", env=affylmGUIenvironment)
                   spliceIndexData <- get("spliceIndexData", env=affylmGUIenvironment)
                   exprConsoleLibs <- get("exprConsoleLibs", env=affylmGUIenvironment)
                   NormalizedAffyData <- get("NormalizedAffyData", env=affylmGUIenvironment)
                   targets.unique <- unique(Targets$Target)
                   #significance parameters
                   threshold <- SpliceIndexDiff
                   Pval <- PvalExon
                   #catching exon info related to a specific gene probeset_id
                   geneExonsIds <- as.vector(unlist(strsplit(exprConsoleLibs$exon.library$"probeset_list"[which(as.character(exprConsoleLibs$exon.library$"probeset_id")==transcriptID)], split=" ")))
                   #transposed the exon matrix
                   geneExons <- spliceIndexData[which(rownames(spliceIndexData)%in%geneExonsIds),]#transpose becausue I need to add the labels
                   ##p.value calculation for exons
                   geneExonsPval <-NULL
                   geneExonsFC <-NULL
                   geneExonsFC.Pval <- NULL
                   geneExons1  <- NULL
                   geneExons2  <- NULL
                   for(t in 1: dim(geneExons)[1]){
                                   geneExonsPval[t]<- -log2(t.test(geneExons[t,which(Targets$Target==targets.unique[1])],geneExons[t,which(Targets$Target==targets.unique[2])])$p.value)
                                   geneExonsFC[t]<- abs(mean(as.vector(unlist(geneExons[t,which(Targets$Target==targets.unique[1])]))) - mean(as.vector(unlist(geneExons[t,which(Targets$Target==targets.unique[2])]))))
                                   geneExons1[t]<- mean(as.vector(unlist(geneExons[t,which(Targets$Target==targets.unique[1])])))
                                   geneExons2[t]<- mean(as.vector(unlist(geneExons[t,which(Targets$Target==targets.unique[2])])))
                                   if(geneExonsFC[t] >= threshold & geneExonsPval[t] >= -log2(Pval)){geneExonsFC.Pval[t] <- 1} else {geneExonsFC.Pval[t] <- 0}
                              }
                   geneExons <- t(spliceIndexData[which(rownames(spliceIndexData)%in%geneExonsIds),])#transpose becasue I need to add the labels
                              
                   exonIndexLablesExons <- NULL
                   for(j in 1: dim(geneExons)[2]){
                                        exonIndexLablesExons    <-  c(exonIndexLablesExons, rep(j,dim(geneExons)[1]))
                                  }    
                             
                   exonIndex <-  seq(1,dim(geneExons)[2])#this is needed since geneExons are going to be transformed in a vector
                   exonIndexLablesSamples <-  rep(Targets$Target,dim(geneExons)[2])

                   geneExons <- as.numeric(unlist(geneExons))  #when unlisting data are unlisted on a column base!
                   if( length(geneExons) > 2 & length(targets.unique)==2){
                                      #defining the index vector for model plotting
                                      index.1 <- NULL
                                      index.2 <- NULL
                                      for(j in 1: length(exonIndex)){
                                                  index.1 <-  c(index.1, intersect(which(exonIndexLablesExons==j), 
                                                                  which(exonIndexLablesSamples==targets.unique[1])))
                                                  index.2 <-  c(index.2, intersect(which(exonIndexLablesExons==j), 
                                                                  which(exonIndexLablesSamples==targets.unique[2])))
                                      }
                                      
                                      lm.geneExons <- lm(geneExons[index.2] ~ geneExons[index.1])
                                      
                                      if(sum(geneExonsFC.Pval) > 0){
                                           par(mfrow=c(2,2))
                                           #plotting exons correlation
                                           plot(geneExons[index.1] , geneExons[index.2], xlab=targets.unique[1], ylab=targets.unique[2], 
                                                           main=paste("gene ID", transcriptID, sep= " "), cex=0.5)
                                           abline(lm.geneExons, lty=2)
                                           pc <- predict(lm.geneExons, int="c")
                                           matlines(geneExons[index.1], pc, lty=c(1,2,2),col=c("black", "red","red"))
                                           
                                           plot(exonIndexLablesExons, geneExons, type="n", xlab="Exon index", ylab="Intensity", 
                                                           main=paste("SI mean diff", threshold, "p-value", Pval,  collapse= " "))
                                           points(exonIndexLablesExons[index.1], geneExons[index.1], pch=19, col="black", cex=0.5)
                                           points(exonIndexLablesExons[index.2], geneExons[index.2], pch=19, col="red", cex=0.5)
                                           lm.geneExons <- lm(geneExons[index.1] ~ exonIndexLablesExons[index.1])
                                           abline(lm.geneExons, lty=2, col="black")
                                           lm.geneExons <- lm(geneExons[index.2] ~ exonIndexLablesExons[index.2])
                                           abline(lm.geneExons, lty=2, col="red")
                                           legend(0,max(geneExons), legend=targets.unique,pch=19, col=c("black","red"))
                                           
                                           plot(geneExons1,geneExonsPval,cex=0.5,xlab="Average mean Splice Index", 
                                                     ylab="Significance of splicing events\n-log2(p-value)", main=targets.unique[1])                
                                           abline(h=-log2(Pval),lty=2, col="green")
                                           text(geneExons1[intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold))],
                                                      geneExonsPval[intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold))],
                                                      labels=c(as.character(intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold)))))
                                          
                                           plot(geneExons2,geneExonsPval,cex=0.5,xlab="Average mean Splice Index", 
                                                     ylab="Significance of splicing events\n-log2(p-value)", main=targets.unique[2])                
                                           abline(h=-log2(Pval),lty=2, col="green")
                                           text(geneExons2[intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold))],
                                                      geneExonsPval[intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold))],
                                                      labels=c(as.character(intersect(which(geneExonsPval >= -log2(Pval)), which(geneExonsFC >= threshold)))))
                                          
                                           
                                           
                                           
                                      }     
                              }
    }
}
################################################################################

# Expression data are filtered on the basis of a list exported by IPA Ingenuity
"midasFilter"<-function(){
      #error if no data are loaded
      Try(whichArrayPlatform <- get("whichArrayPlatform",envir=affylmGUIenvironment))
      if(whichArrayPlatform ==""){
              Try(tkmessageBox(title="Exons analysis",message="No arrays have been loaded.	Please try New or Open from the File menu.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
      }    
      #########################

     Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
     Try(midas.p.Available <- get("midas.p.Available", env=affylmGUIenvironment))
#     Try(exonAffyData.Available <- get("exonAffyData.Available", env=affylmGUIenvironment))
     Try(spliceIndexData.Available <- get("spliceIndexData.Available", env=affylmGUIenvironment))
     
     if(!midas.p.Available){
              Try(tkmessageBox(title="Exons analysis",message="MiDAS p-values are not available\nYou need to calculate them before using this function.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
    } 
     
     if(midas.p.Available & spliceIndexData.Available){
            #assigning midas threshold graphical menu
                 Try(ttGetMidas<-tktoplevel(.affylmGUIglobals$ttMain))
                 Try(tkwm.deiconify(ttGetMidas))
                 Try(tkgrab.set(ttGetMidas))
                 Try(tkfocus(ttGetMidas))
                 Try(tkwm.title(ttGetMidas,"Assigning MiDAS threshold"))
                 Try(tkgrid(tklabel(ttGetMidas,text="    ")))
                 Try(Midasnum <- "0.05")
                 Try(Local.Midas <- tclVar(init=Midasnum))
                 Try(entry.Midas <-tkentry(ttGetMidas,width="4",font=.affylmGUIglobals$affylmGUIfont2,textvariable=Local.Midas,bg="white"))
                 Try(tkgrid(tklabel(ttGetMidas,text="Please enter a p-value threshold.",font=.affylmGUIglobals$affylmGUIfont2)))
                 Try(tkgrid(entry.Midas))
                 onOK <- function()
                 {
                     Try(Midasnum <- as.numeric(tclvalue(Local.Midas)))
                     Try(assign("Midasnum",Midasnum,affylmGUIenvironment))
                     Try(tclvalue(.affylmGUIglobals$MidasnumTcl) <- Midasnum)
                     Try(tkgrab.release(ttGetMidas));Try(tkdestroy(ttGetMidas));Try(tkfocus(.affylmGUIglobals$ttMain))                        
                 }
                 Try(OK.but <-tkbutton(ttGetMidas,text="   OK   ",command=onOK,font=.affylmGUIglobals$affylmGUIfont2))
                 Try(tkgrid(tklabel(ttGetMidas,text="    ")))
                 Try(tkgrid(OK.but))
                 Try(tkgrid.configure(OK.but))
                 Try(tkgrid(tklabel(ttGetMidas,text="       ")))
                 Try(tkfocus(entry.Midas))
                 Try(tkbind(entry.Midas, "<Return>",onOK))
                 Try(tkbind(ttGetMidas, "<Destroy>", function(){Try(tkgrab.release(ttGetMidas));Try(tkfocus(.affylmGUIglobals$ttMain));return(0)}))
                 Try(tkwait.window(ttGetMidas))
                 Try(tkfocus(.affylmGUIglobals$ttMain))
                                                                   
                 Try(midas.p <- get("midas.p", env=affylmGUIenvironment))
                 Try(spliceIndexData <- get("spliceIndexData", env=affylmGUIenvironment))
                 Try(NormalizedAffyData <- get("NormalizedAffyData", env=affylmGUIenvironment))
                 Try(exonAffyData <- get("exonAffyData", env=affylmGUIenvironment))
                 Try(x.lib <- affylmGUIenvironment$exprConsoleLibs$exon.library)
                 Try(Midasnum <- get("Midasnum", env= affylmGUIenvironment))
                 Try(which <- midas.p[which(midas.p[,3] <= Midasnum),2])
                 Try(which <- unique(which))
                 Try(NormalizedAffyData <- NormalizedAffyData[which(featureNames(NormalizedAffyData)%in%as.character(which)),])
                 Try(assign("NormalizedAffyData",NormalizedAffyData,affylmGUIenvironment))
                 Try(x.lib.subset <- x.lib[which(x.lib[,1]%in%featureNames(NormalizedAffyData)),3]) #in the list obtained from NetAffx there are all the probe set ids and I have to subset only those related to the exon library loaded with the data set
                 Try(x.lib.subset <- sapply(x.lib.subset ,function(x){strsplit(x, " ")}))
                 Try(x.lib.subset<-as.vector(unlist(x.lib.subset)))
                 Try(exonAffyData <- exonAffyData[which(featureNames(exonAffyData)%in%x.lib.subset),])
                 Try(assign("exonAffyData",exonAffyData,affylmGUIenvironment))
                 Try(spliceIndexData <- spliceIndexData[which(spliceIndexData[,1]%in%x.lib.subset),])
                 Try(assign("spliceIndexData",spliceIndexData,affylmGUIenvironment))
                
                 Try(info.dataset<-paste("Genes= ", dim(exprs(NormalizedAffyData))[1],"\n",
                                         "Exons= ", dim(exprs(exonAffyData))[1],"\n",
                                         "SI= ",    dim(spliceIndexData)[1],"\n",
                                         "Samples= ", dim(exprs(NormalizedAffyData))[2],"\n",
                                         "Annotation library= ", annotation(NormalizedAffyData),"\n", sep=""))
                Try(tkmessageBox(title="Summary of MiDAS putative alternative splicing events",message=info.dataset))
                Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
               #######################################################

            
            
            
     } else Try(tkmessageBox(title="Filtering by MiDAS p-values",message="You have to calculate MiDAS p-value first!\n See exon level menu.", type="ok", icon="error"))  

}
################################################################################

erankProdAltSplFilter <- function(){
     #error if no data are loaded
     Try(whichArrayPlatform <- get("whichArrayPlatform",envir=affylmGUIenvironment))
     if(whichArrayPlatform ==""){
              Try(tkmessageBox(title="Exons analysis",message="No arrays have been loaded.	Please try New or Open from the File menu.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
     }    
     Try(spliceIndexData.Available <- get("spliceIndexData.Available", env=affylmGUIenvironment))
     Try(AltSplRP.e.Available <- get("AltSplRP.e.Available", env=affylmGUIenvironment))

     if(!spliceIndexData.Available){
              Try(tkmessageBox(title="Exons analysis",message="Splice Index is not available\nYou need to calculate it before using this function.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
    }
    if(!AltSplRP.e.Available){
              Try(tkmessageBox(title="Exons analysis",message="RP alternative splicing detection is not available\nYou need to calculate it before using this function.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
    } 
    Try(AltSplRP.e.p <- get("AltSplRP.e.p", env=affylmGUIenvironment))
                #assigning midas threshold graphical menu
                 Try(ttGetAltSplRP<-tktoplevel(.affylmGUIglobals$ttMain))
                 Try(tkwm.deiconify(ttGetAltSplRP))
                 Try(tkgrab.set(ttGetAltSplRP))
                 Try(tkfocus(ttGetAltSplRP))
                 Try(tkwm.title(ttGetAltSplRP,"Assigning RP threshold"))
                 Try(tkgrid(tklabel(ttGetAltSplRP,text="    ")))
                 Try(AltSplRPnum <- "0.05")
                 Try(Local.AltSplRP <- tclVar(init=AltSplRPnum))
                 Try(entry.AltSplRP <-tkentry(ttGetAltSplRP,width="4",font=.affylmGUIglobals$affylmGUIfont2,textvariable=Local.AltSplRP,bg="white"))
                 Try(tkgrid(tklabel(ttGetAltSplRP,text="Please enter a p-value threshold.",font=.affylmGUIglobals$affylmGUIfont2)))
                 Try(tkgrid(entry.AltSplRP))
                 onOK <- function()
                 {
                     Try(Midasnum <- as.numeric(tclvalue(Local.AltSplRP)))
                     Try(assign("AltSplRPnum",AltSplRPnum,affylmGUIenvironment))
                     Try(tclvalue(.affylmGUIglobals$AltSplRPnumTcl) <- AltSplRPnum)
                     Try(tkgrab.release(ttGetAltSplRP));Try(tkdestroy(ttGetAltSplRP));Try(tkfocus(.affylmGUIglobals$ttMain))                        
                 }
                 Try(OK.but <-tkbutton(ttGetAltSplRP,text="   OK   ",command=onOK,font=.affylmGUIglobals$affylmGUIfont2))
                 Try(tkgrid(tklabel(ttGetAltSplRP,text="    ")))
                 Try(tkgrid(OK.but))
                 Try(tkgrid.configure(OK.but))
                 Try(tkgrid(tklabel(ttGetAltSplRP,text="       ")))
                 Try(tkfocus(entry.AltSplRP))
                 Try(tkbind(entry.AltSplRP, "<Return>",onOK))
                 Try(tkbind(ttGetAltSplRP, "<Destroy>", function(){Try(tkgrab.release(ttGetAltSplRP));Try(tkfocus(.affylmGUIglobals$ttMain));return(0)}))
                 Try(tkwait.window(ttGetAltSplRP))
                 Try(tkfocus(.affylmGUIglobals$ttMain))
                                                                   
                 Try(AltSplRP.e.p <- get("AltSplRP.e.p", env=affylmGUIenvironment))
                 Try(spliceIndexData <- get("spliceIndexData", env=affylmGUIenvironment))
                 Try(NormalizedAffyData <- get("NormalizedAffyData", env=affylmGUIenvironment))
                 Try(exonAffyData <- get("exonAffyData", env=affylmGUIenvironment))
                 Try(x.lib <- affylmGUIenvironment$exprConsoleLibs$exon.library)
                 Try(AltSplRPnum <- get("AltSplRPnum", env= affylmGUIenvironment))
                 Try(which1 <- AltSplRP.e.p[which(AltSplRP.e.p[,2] <= AltSplRPnum),1])
                 Try(which2 <- AltSplRP.e.p[which(AltSplRP.e.p[,3] <= AltSplRPnum),1])
                 Try(which <- unique(c(as.character(which1),as.character(which2))))
                 Try(which <- strsplit(which, "\\|"))#first exon inds second transcript id
                 Try(which1 <- sapply(which, function(x){x[1]}))#exon ids
                 Try(which2 <- sapply(which, function(x){x[2]}))#gene ids
                 Try(NormalizedAffyData <- NormalizedAffyData[which(featureNames(NormalizedAffyData)%in%which2),])
                 Try(assign("NormalizedAffyData",NormalizedAffyData,affylmGUIenvironment))
                 Try(x.lib.subset <- x.lib[which(x.lib[,1]%in%featureNames(NormalizedAffyData)),3]) #in the list obtained from NetAffx there are all the probe set ids and I have to subset only those related to the exon library loaded with the data set
                 Try(x.lib.subset <- sapply(x.lib.subset ,function(x){strsplit(x, " ")}))
                 Try(x.lib.subset<-as.vector(unlist(x.lib.subset)))
                 Try(exonAffyData <- exonAffyData[which(featureNames(exonAffyData)%in%x.lib.subset),])
                 Try(assign("exonAffyData",exonAffyData,affylmGUIenvironment))
                 Try(spliceIndexData <- spliceIndexData[which(spliceIndexData[,1]%in%x.lib.subset),])
                 Try(assign("spliceIndexData",spliceIndexData,affylmGUIenvironment))
                
                 Try(info.dataset<-paste("Genes= ", dim(exprs(NormalizedAffyData))[1],"\n",
                                         "Exons= ", dim(exprs(exonAffyData))[1],"\n",
                                         "SI= ",    dim(spliceIndexData)[1],"\n",
                                         "Samples= ", dim(exprs(NormalizedAffyData))[2],"\n",
                                         "Annotation library= ", annotation(NormalizedAffyData),"\n", sep=""))
                Try(tkmessageBox(title="Summary of RP putative alternative splicing events",message=info.dataset))
                                  par(mfrow=c(1,3))
                  Try(hist(AltSplRP.e.p[,2], main=names(AltSplRP.e.p)[2]))
                  Try(hist(AltSplRP.e.p[,3], main=names(AltSplRP.e.p)[3]))
                  Try(hist(AltSplRP.e.p[,4], main=names(AltSplRP.e.p)[4]))
                 Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
               #######################################################
  
}


################################################################################

crosshybFilter <- function(){
    
          #error if no data are loaded
          Try(whichArrayPlatform <- get("whichArrayPlatform",envir=affylmGUIenvironment))
          if(whichArrayPlatform !="EXON"){
              Try(tkmessageBox(title="Filtering",message="No exon arrays have been loaded.	Please try New or Open from the File menu.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
          }    
        	##makning the menu for selecting Type of cross hyb filter
            Try(ttGetHybFilterMethod <- tktoplevel(.affylmGUIglobals$ttMain))
	      Try(tkwm.deiconify(ttGetHybFilterMethod))
            Try(tkgrab.set(ttGetHybFilterMethod))
            Try(tkfocus(ttGetHybFilterMethod))
            Try(tkwm.title(ttGetHybFilterMethod,"Cross hybridization filter"))
	
 	      Try(tkgrid(tklabel(ttGetHybFilterMethod,text="    ")))
	      Try(ttGetHybFilterMethodTcl <- tclVar("23"))
            Try(rbXHYB <- tkradiobutton(ttGetHybFilterMethod,text="XHYB (TRUE)",variable=ttGetHybFilterMethodTcl,value="TRUE",font=.affylmGUIglobals$affylmGUIfont2))
            Try(rbCHYB2<-tkradiobutton(ttGetHybFilterMethod,text="CROSS HYB = similar",variable=ttGetHybFilterMethodTcl,value="2",font=.affylmGUIglobals$affylmGUIfont2))
            Try(rbCHYB3<-tkradiobutton(ttGetHybFilterMethod,text="CROSS HYB = mixed",variable=ttGetHybFilterMethodTcl,value="3",font=.affylmGUIglobals$affylmGUIfont2))
            Try(rbCHYB23<-tkradiobutton(ttGetHybFilterMethod,text="CROSS HYB = similar and mixed",variable=ttGetHybFilterMethodTcl,value="23",font=.affylmGUIglobals$affylmGUIfont2))

	      Try(tkgrid(tklabel(ttGetHybFilterMethod,text="    "),rbXHYB))
	      Try(tkgrid(tklabel(ttGetHybFilterMethod,text="    "),rbCHYB2))
	      Try(tkgrid(tklabel(ttGetHybFilterMethod,text="    "),rbCHYB3))
	      Try(tkgrid(tklabel(ttGetHybFilterMethod,text="    "),rbCHYB23))
	      Try(tkgrid.configure(rbXHYB,rbCHYB2,rbCHYB3,rbCHYB23,columnspan=2,sticky="w"))
	      Try(tkgrid(tklabel(ttGetHybFilterMethod,text="    "),tklabel(ttGetHybFilterMethod,text="    ")))
	      Try(ReturnVal <- "")
	      Try(onCancel <- function() {Try(ReturnVal <<- "");Try(tkgrab.release(ttGetHybFilterMethod));Try(tkdestroy(ttGetHybFilterMethod));Try(tkfocus(.affylmGUIglobals$ttMain))})
	      Try(onOK <- function() {Try(ReturnVal <<- tclvalue(ttGetHybFilterMethodTcl));Try(tkgrab.release(ttGetHybFilterMethod));Try(tkdestroy(ttGetHybFilterMethod));Try(tkfocus(.affylmGUIglobals$ttMain))})
        Try(onHelp <- function() tkmessageBox(title="Cross hybridization exon probe set filtering",
                 message="Cross hybridizing exon probe sets can be removed using the XHYB annotation or the CROSSHYB annotation.
                           \nSimilar: All the probes in the probe set perfectly match more than one sequence in the putatively transcribed array design content.
                           \nMixed: The probes in the probe set either perfectly match or partially match more than one sequence in the putatively transcribed array design content.
                           \nThe filter removes all the gene/exon level probe sets belonging to the selected item",
                 icon="info"))
        Try(Help.but <- tkbutton(ttGetHybFilterMethod,text=" Help ",command=function()Try(onHelp()),font=.affylmGUIglobals$affylmGUIfont2))
	      Try(OK.but     <- tkbutton(ttGetHybFilterMethod,text="OK",command=onOK,font=.affylmGUIglobals$affylmGUIfont2))
	      Try(Cancel.but <- tkbutton(ttGetHybFilterMethod,text="Cancel",command=onCancel,font=.affylmGUIglobals$affylmGUIfont2))

	      Try(tkgrid(tklabel(ttGetHybFilterMethod,text="    "),OK.but,Cancel.but, Help.but,tklabel(ttGetHybFilterMethod,text="    ")))
	      Try(tkgrid.configure(OK.but,sticky="e"))
	      Try(tkgrid.configure(Cancel.but,sticky="w"))
	      Try(tkgrid.configure(Help.but,sticky="e"))
	      Try(tkgrid(tklabel(ttGetHybFilterMethod,text="    ")))

	      Try(tkbind(ttGetHybFilterMethod,"<Destroy>",function() {ReturnVal <- "";Try(tkgrab.release(ttGetHybFilterMethod));Try(tkfocus(.affylmGUIglobals$ttMain));}))
       Try(tkbind(OK.but, "<Return>",onOK))
       Try(tkbind(Cancel.but, "<Return>",onCancel))      
        Try(tkbind(Help.but, "<Return>",onCancel)) 
	      Try(tkwait.window(ttGetHybFilterMethod))
	      if(ReturnVal==""){
                              Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
                              return()
        } else if (ReturnVal=="2"){
                  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
                  #extracting the library
                  Try(whichLib <- get("whichLib",envir=affylmGUIenvironment))
                  Try(annlibloc <- grep(paste("crosshyb",whichLib[[1]][1],sep=""), as.vector(unlist(data(package="oneChannelGUI"))), ignore.case = T))
                  Try(annlibname <- as.vector(unlist(data(package="oneChannelGUI")))[annlibloc])
                  Try(data(list=annlibname,package="oneChannelGUI"))
                  Try(exonannlib<- get(annlibname,envir=.GlobalEnv))
                  Try(x <- get("NormalizedAffyData",envir=affylmGUIenvironment))
                  Try(which <- unique(as.character(exonannlib[which(exonannlib$CROSSHYBTYPE!=2),2])))
                  par(mfrow=c(1,2))
                  Try(text<-paste("Unfiltered probes= ", dim(exprs(x))[1], sep=""))
                  Try(hist(as.matrix(exprs(x)), breaks=100, main=text))
                  Try(assign("NormalizedAffyData", x[which(featureNames(x)%in%which),],  envir=affylmGUIenvironment))
                  Try(NormalizedAffyData <- get("NormalizedAffyData", envir=affylmGUIenvironment)) 
                  Try(text<-paste("Filtered probes= ", dim(exprs(NormalizedAffyData))[1], "\nwithout similar crosshyb type",sep=""))
                  Try(hist(as.matrix(exprs(x[which(featureNames(x)%in%which),])), breaks=100, main=text))
#                  Try(assign("NormalizedAffyData", x[which(featureNames(x)%in%which),],  envir=affylmGUIenvironment))
                  Try(x.exon <- get("exonAffyData",envir=affylmGUIenvironment))
                  ####temporary saving unfiltered data
                  Try(tempUnfiltered <- tempfile(pattern = "unfiltered", tmpdir = ""))
                  Try(tempUnfiltered <- sub( "\\\\","",tempUnfiltered)) 
                  Try(tempUnfiltered <- paste(tempUnfiltered, ".rda", sep=""))
                  Try(assign("unfilteredData.location", tempUnfiltered, envir=affylmGUIenvironment))
                  Try(save(x, x.exon, file=tempUnfiltered))
                  ####temporary saving unfiltered data
                  Try(x <- x[which(featureNames(x)%in%which),])
                  tkdelete(.affylmGUIglobals$mainTree,"NormalizedAffyData.Status")
                  tkinsert(.affylmGUIglobals$mainTree,"end","NormalizedAffyData","NormalizedAffyData.Status" ,text="Available wo similar",font=.affylmGUIglobals$affylmGUIfontTree)
                  Try(x.lib <- affylmGUIenvironment$exprConsoleLibs$exon.library)
                  Try(x.lib.subset <- x.lib[which(x.lib[,1]%in%as.numeric(featureNames(x))),3])
                  Try(x.lib.subset <- sapply(x.lib.subset ,function(x){strsplit(x, " ")}))
                  Try(x.lib.subset<-as.vector(unlist(x.lib.subset)))
                  Try(assign("exonAffyData", x.exon[which(featureNames(x.exon)%in%x.lib.subset),], envir=affylmGUIenvironment))
                  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
        } else if (ReturnVal=="3"){
                  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
                  #extracting the library
                  Try(whichLib <- get("whichLib",envir=affylmGUIenvironment))
                  Try(annlibloc <- grep(paste("crosshyb",whichLib[[1]][1],sep=""), as.vector(unlist(data(package="oneChannelGUI"))), ignore.case = T))
                  Try(annlibname <- as.vector(unlist(data(package="oneChannelGUI")))[annlibloc])
                  Try(data(list=annlibname,package="oneChannelGUI"))
                  Try(exonannlib<- get(annlibname,envir=.GlobalEnv))
                  Try(x <- get("NormalizedAffyData",envir=affylmGUIenvironment))
                  Try(which <- unique(as.character(exonannlib[which(exonannlib$CROSSHYBTYPE!=3),2])))
                  par(mfrow=c(1,2))
                  Try(text<-paste("Unfiltered probes= ", dim(exprs(x))[1], sep=""))
                  Try(hist(as.matrix(exprs(x)), breaks=100, main=text))
                  Try(assign("NormalizedAffyData", x[which(featureNames(x)%in%which),],  envir=affylmGUIenvironment))
                  Try(NormalizedAffyData <- get("NormalizedAffyData", envir=affylmGUIenvironment)) 
                  Try(text<-paste("Filtered probes= ", dim(exprs(NormalizedAffyData))[1], "\nwithout mixed crosshyb type",sep=""))
                  Try(hist(as.matrix(exprs(x[which(featureNames(x)%in%which),])), breaks=100, main=text))
#                  Try(assign("NormalizedAffyData", x[which(featureNames(x)%in%which),],  envir=affylmGUIenvironment))
                  Try(x.exon <- get("exonAffyData",envir=affylmGUIenvironment))
                  ####temporary saving unfiltered data
                  Try(tempUnfiltered <- tempfile(pattern = "unfiltered", tmpdir = ""))
                  Try(tempUnfiltered <- sub( "\\\\","",tempUnfiltered)) 
                  Try(tempUnfiltered <- paste(tempUnfiltered, ".rda", sep=""))
                  Try(assign("unfilteredData.location", tempUnfiltered, envir=affylmGUIenvironment))
                  Try(save(x, x.exon, file=tempUnfiltered))
                  ####temporary saving unfiltered data
                  Try(x <- x[which(featureNames(x)%in%which),])
                  tkdelete(.affylmGUIglobals$mainTree,"NormalizedAffyData.Status")
                  tkinsert(.affylmGUIglobals$mainTree,"end","NormalizedAffyData","NormalizedAffyData.Status" ,text="Available wo mixed",font=.affylmGUIglobals$affylmGUIfontTree)
                  Try(x.lib <- affylmGUIenvironment$exprConsoleLibs$exon.library)
                  Try(x.lib.subset <- x.lib[which(x.lib[,1]%in%as.numeric(featureNames(x))),3])
                  Try(x.lib.subset <- sapply(x.lib.subset ,function(x){strsplit(x, " ")}))
                  Try(x.lib.subset<-as.vector(unlist(x.lib.subset)))
                  Try(assign("exonAffyData", x.exon[which(featureNames(x.exon)%in%x.lib.subset),], envir=affylmGUIenvironment))
                  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
        } else if (ReturnVal=="23"){
                  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
                  #extracting the library
                  Try(whichLib <- get("whichLib",envir=affylmGUIenvironment))
                  Try(annlibloc <- grep(paste("crosshyb",whichLib[[1]][1],sep=""), as.vector(unlist(data(package="oneChannelGUI"))), ignore.case = T))
                  Try(annlibname <- as.vector(unlist(data(package="oneChannelGUI")))[annlibloc])
                  Try(data(list=annlibname,package="oneChannelGUI"))
                  Try(exonannlib<- get(annlibname,envir=.GlobalEnv))
                  Try(x <- get("NormalizedAffyData",envir=affylmGUIenvironment))
                  Try(which <- unique(as.character(exonannlib[which(exonannlib$CROSSHYBTYPE==1),2])))
                  par(mfrow=c(1,2))
                  Try(text<-paste("Unfiltered probes= ", dim(exprs(x))[1], sep=""))
                  Try(hist(as.matrix(exprs(x)), breaks=100, main=text))
                  Try(assign("NormalizedAffyData", x[which(featureNames(x)%in%which),],  envir=affylmGUIenvironment))
                  Try(NormalizedAffyData <- get("NormalizedAffyData", envir=affylmGUIenvironment)) 
                  Try(text<-paste("Filtered probes= ", dim(exprs(NormalizedAffyData))[1], "\nwithout mixed/similar crosshyb types",sep=""))
                  Try(hist(as.matrix(exprs(x[which(featureNames(x)%in%which),])), breaks=100, main=text))
#                  Try(assign("NormalizedAffyData", x[which(featureNames(x)%in%which),],  envir=affylmGUIenvironment))
                  Try(x.exon <- get("exonAffyData",envir=affylmGUIenvironment))
                  ####temporary saving unfiltered data
                  Try(tempUnfiltered <- tempfile(pattern = "unfiltered", tmpdir = ""))
                  Try(tempUnfiltered <- sub( "\\\\","",tempUnfiltered)) 
                  Try(tempUnfiltered <- paste(tempUnfiltered, ".rda", sep=""))
                  Try(assign("unfilteredData.location", tempUnfiltered, envir=affylmGUIenvironment))
                  Try(save(x, x.exon, file=tempUnfiltered))
                  ####temporary saving unfiltered data
                  Try(x <- x[which(featureNames(x)%in%which),])
                  tkdelete(.affylmGUIglobals$mainTree,"NormalizedAffyData.Status")
                  tkinsert(.affylmGUIglobals$mainTree,"end","NormalizedAffyData","NormalizedAffyData.Status" ,text="Available wo mixed/similar",font=.affylmGUIglobals$affylmGUIfontTree)
                  Try(x.lib <- affylmGUIenvironment$exprConsoleLibs$exon.library)
                  Try(x.lib.subset <- x.lib[which(x.lib[,1]%in%as.numeric(featureNames(x))),3])
                  Try(x.lib.subset <- sapply(x.lib.subset ,function(x){strsplit(x, " ")}))
                  Try(x.lib.subset<-as.vector(unlist(x.lib.subset)))
                  Try(assign("exonAffyData", x.exon[which(featureNames(x.exon)%in%x.lib.subset),], envir=affylmGUIenvironment))
                  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
        } else if (ReturnVal=="TRUE"){
                  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
                  #extracting the library
                  Try(whichLib <- get("whichLib",envir=affylmGUIenvironment))
                  Try(annlibloc <- grep(paste("crosshyb",whichLib[[1]][1],sep=""), as.vector(unlist(data(package="oneChannelGUI"))), ignore.case = T))
                  Try(annlibname <- as.vector(unlist(data(package="oneChannelGUI")))[annlibloc])
                  Try(data(list=annlibname,package="oneChannelGUI"))
                  Try(exonannlib<- get(annlibname,envir=.GlobalEnv))
                  Try(x <- get("NormalizedAffyData",envir=affylmGUIenvironment))
                  Try(which1 <- unique(as.character(exonannlib[which(exonannlib$XHYB=="TRUE"),2])))
                  Try(which2 <- unique(as.character(exonannlib[is.na(exonannlib$XHYB),2])))
                  Try(which <- setdiff(featureNames(x),c(which1, which2)))
                  par(mfrow=c(1,2))
                  Try(text<-paste("Unfiltered probes= ", dim(exprs(x))[1], sep=""))
                  Try(hist(as.matrix(exprs(x)), breaks=100, main=text))
                  Try(assign("NormalizedAffyData", x[which(featureNames(x)%in%which),],  envir=affylmGUIenvironment))
                  Try(NormalizedAffyData <- get("NormalizedAffyData", envir=affylmGUIenvironment)) 
                  Try(text<-paste("Filtered probes= ", dim(exprs(NormalizedAffyData))[1], "\nwithout xhyb type",sep=""))
                  Try(hist(as.matrix(exprs(x[which(featureNames(x)%in%which),])), breaks=100, main=text))
#                  Try(assign("NormalizedAffyData", x[which(featureNames(x)%in%which),],  envir=affylmGUIenvironment))
                  Try(x.exon <- get("exonAffyData",envir=affylmGUIenvironment))
                  ####temporary saving unfiltered data
                  Try(tempUnfiltered <- tempfile(pattern = "unfiltered", tmpdir = ""))
                  Try(tempUnfiltered <- sub( "\\\\","",tempUnfiltered)) 
                  Try(tempUnfiltered <- paste(tempUnfiltered, ".rda", sep=""))
                  Try(assign("unfilteredData.location", tempUnfiltered, envir=affylmGUIenvironment))
                  Try(save(x, x.exon, file=tempUnfiltered))
                  ####temporary saving unfiltered data
                  Try(x <- x[which(featureNames(x)%in%which),])
                  tkdelete(.affylmGUIglobals$mainTree,"NormalizedAffyData.Status")
                  tkinsert(.affylmGUIglobals$mainTree,"end","NormalizedAffyData","NormalizedAffyData.Status" ,text="Available wo xhyb",font=.affylmGUIglobals$affylmGUIfontTree)
                  Try(x.lib <- affylmGUIenvironment$exprConsoleLibs$exon.library)
                  Try(x.lib.subset <- x.lib[which(x.lib[,1]%in%as.numeric(featureNames(x))),3])
                  Try(x.lib.subset <- sapply(x.lib.subset ,function(x){strsplit(x, " ")}))
                  Try(x.lib.subset<-as.vector(unlist(x.lib.subset)))
                  Try(assign("exonAffyData", x.exon[which(featureNames(x.exon)%in%x.lib.subset),], envir=affylmGUIenvironment))
                  Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
        }



}

################################################################################
simFilter <- function(){
          #error if no data are loaded
          Try(whichArrayPlatform <- get("whichArrayPlatform",envir=affylmGUIenvironment))
          if(whichArrayPlatform !="EXON"){
              Try(tkmessageBox(title="Filtering by SI mean difference",message="No exon arrays have been loaded.	Please try New or Open from the File menu.",type="ok",icon="error"))
				    	Try(tkfocus(.affylmGUIglobals$ttMain))
              Try(return())
          }    
        	##makning the menu for selecting the amount of average SI mean difference
          Try(targets <-  affylmGUIenvironment$Targets$Target)
          Try(target.unique <- unique(targets))
          Try(cl <- rep(0,length(targets)))

          if(length(target.unique) == 2){
                 #groups definition
                 Try(tkmessageBox(title="Filtering by SI mean difference",message="Two-Class case analysis will be performed."))
                 Try(cl[which(targets==target.unique[2])] <- 1)
                 Try(spliceIndexData.Available <- get("spliceIndexData.Available", env=affylmGUIenvironment))
                 if(spliceIndexData.Available){
                        Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="watch"))
                        Try(spliceIndexData <- get("spliceIndexData", env=affylmGUIenvironment))
                        Try(cl <- as.numeric(c("NA","NA",cl)))
                        Try(mean.c <- apply(spliceIndexData[,which(cl==0)], 1, mean))
                        Try(mean.t <- apply(spliceIndexData[,which(cl==1)], 1, mean))
                        Try(amsi <- abs(mean.t - mean.c))
                        
                        ######################Selecting fc threshold
                       Try(ttThresholdFC<-tktoplevel(.affylmGUIglobals$ttMain))
                       Try(tkwm.deiconify(ttThresholdFC))
                       Try(tkgrab.set(ttThresholdFC))
                       Try(tkfocus(ttThresholdFC))
                       Try(tkwm.title(ttThresholdFC,"|FC| threshold"))
                       Try(tkgrid(tklabel(ttThresholdFC,text="    ")))
                       Try(ThresholdFC <- "")
                       Try(Local.FileName <- tclVar(init=ThresholdFC))
                       Try(entry.FileName <-tkentry(ttThresholdFC,width="10",font=.affylmGUIglobals$affylmGUIfont2,textvariable=Local.FileName,bg="white"))
                       Try(tkgrid(tklabel(ttThresholdFC,text="Please, enter the absolute SI mean difference \nof your choice.",font=.affylmGUIglobals$affylmGUIfont2)))
                       Try(tkgrid(entry.FileName))
                       onOK <- function()
                       {
                             Try(ThresholdFC <- tclvalue(Local.FileName))
                             if(nchar(ThresholdFC)==0)
                                 Try(ThresholdFC <- 0)
                             Try(assign("ThresholdFC",ThresholdFC,affylmGUIenvironment))
                             Try(tclvalue(.affylmGUIglobals$ThresholdFCTcl) <- ThresholdFC)
                             Try(tkgrab.release(ttThresholdFC));Try(tkdestroy(ttThresholdFC));Try(tkfocus(.affylmGUIglobals$ttMain))
                       }
                       Try(OK.but <-tkbutton(ttThresholdFC,text="   OK   ",command=onOK,font=.affylmGUIglobals$affylmGUIfont2))
                       Try(tkgrid(tklabel(ttThresholdFC,text="    ")))
                       Try(tkgrid(OK.but))
                       Try(tkgrid.configure(OK.but))
                       Try(tkgrid(tklabel(ttThresholdFC,text="       ")))
                       Try(tkfocus(entry.FileName))
                       Try(tkbind(entry.FileName, "<Return>",onOK))
                       Try(tkbind(ttThresholdFC, "<Destroy>", function(){Try(tkgrab.release(ttThresholdFC));Try(tkfocus(.affylmGUIglobals$ttMain));return(0)}))
                       Try(tkwait.window(ttThresholdFC))
                       Try(tkfocus(.affylmGUIglobals$ttMain))
                                           
                       Try(fold.change <- as.numeric(affylmGUIenvironment$ThresholdFC))
                       Try(selGlevel <- spliceIndexData[which(amsi >= fold.change),2])
                       
                           Try( x <- get("NormalizedAffyData",envir=affylmGUIenvironment))
                           Try(x.exon <- get("exonAffyData",envir=affylmGUIenvironment))
                            ####temporary saving unfiltered data
                            Try(tempUnfiltered <- tempfile(pattern = "unfiltered", tmpdir = "") )
                            Try(tempUnfiltered <- sub( "\\\\","",tempUnfiltered)) 
                            Try(tempUnfiltered <- paste(tempUnfiltered, ".rda", sep=""))
                            Try(assign("unfilteredData.location", tempUnfiltered, envir=affylmGUIenvironment))
                            Try(save(x, x.exon, file=tempUnfiltered))
                            ####temporary saving unfiltered data
                           Try(x <- x[which(featureNames(x)%in%selGlevel),])#subset of probe set to be used to extract exon data
                           Try(assign("NormalizedAffyData", x, envir=affylmGUIenvironment))
                           Try(tkdelete(.affylmGUIglobals$mainTree,"NormalizedAffyData.Status"))
                           Try(tkinsert(.affylmGUIglobals$mainTree,"end","NormalizedAffyData","NormalizedAffyData.Status" ,text="Available from SI mean diff. filter.",font=.affylmGUIglobals$affylmGUIfontTree))
                           Try( x.lib <- affylmGUIenvironment$exprConsoleLibs$exon.library)
                           Try( x.lib.subset <- x.lib[which(x.lib[,1]%in%as.numeric(featureNames(x))),3])
                           Try( x.lib.subset <- sapply(x.lib.subset ,function(x){strsplit(x, " ")}))
                           Try( x.lib.subset<-as.vector(unlist(x.lib.subset)))
                           Try( affylmGUIenvironment$exonAffyData <- x.exon[which(featureNames(x.exon)%in%x.lib.subset),])
                           Try(showDataset()) 
                       Try(tkconfigure(.affylmGUIglobals$ttMain,cursor="arrow"))
                 } else {
                         Try(tkmessageBox(title="Filtering by SI mean difference",message="Splice Index values are not available. Use the APT MiDAS function in exon menu.",type="ok",icon="error"))
				    	           Try(tkfocus(.affylmGUIglobals$ttMain))
                         Try(return())
                 }
                 
          } else {
                         Try(tkmessageBox(title="Filtering by SI mean difference",message="This function works only for a two-class case.",type="ok",icon="error"))
				    	           Try(tkfocus(.affylmGUIglobals$ttMain))
                         Try(return())
          }
}

################################################################################